---
sidebar_label: dict
title: data_structures.predefined.dict
---

## Dict Objects

```python
class Dict(DataStructure)
```

This class serializes python dict

soil.data(my_dict) will create a dict automatically.

